@@ -1,82 +1,90 @@
-( cd opt/kde/lib ; rm -rf libworkman.so )
-( cd opt/kde/lib ; ln -sf libworkman.so.1.4.3 libworkman.so )
-( cd opt/kde/lib ; rm -rf libartsgui.so.0 )
-( cd opt/kde/lib ; ln -sf libartsgui.so.0.0.0 libartsgui.so.0 )
-( cd opt/kde/lib ; rm -rf libartsmidi_idl.so )
-( cd opt/kde/lib ; ln -sf libartsmidi_idl.so.0.0.0 libartsmidi_idl.so )
-( cd opt/kde/lib ; rm -rf libartsmidi.so )
-( cd opt/kde/lib ; ln -sf libartsmidi.so.0.0.0 libartsmidi.so )
-( cd opt/kde/lib ; rm -rf libnoatun.so )
-( cd opt/kde/lib ; ln -sf libnoatun.so.0.0.0 libnoatun.so )
-( cd opt/kde/lib ; rm -rf libyafcore.so )
-( cd opt/kde/lib ; ln -sf libyafcore.so.0.0.0 libyafcore.so )
-( cd opt/kde/lib ; rm -rf libmpeg.so )
-( cd opt/kde/lib ; ln -sf libmpeg-0.3.0.so libmpeg.so )
-( cd opt/kde/lib ; rm -rf libyafxplayer.so.0 )
-( cd opt/kde/lib ; ln -sf libyafxplayer.so.0.0.0 libyafxplayer.so.0 )
-( cd opt/kde/lib ; rm -rf libnoatuncontrols.so )
-( cd opt/kde/lib ; ln -sf libnoatuncontrols.so.0.0.0 libnoatuncontrols.so )
-( cd opt/kde/lib ; rm -rf libartsmidi_idl.so.0 )
-( cd opt/kde/lib ; ln -sf libartsmidi_idl.so.0.0.0 libartsmidi_idl.so.0 )
-( cd opt/kde/lib ; rm -rf libartsgui_idl.so )
-( cd opt/kde/lib ; ln -sf libartsgui_idl.so.0.0.0 libartsgui_idl.so )
-( cd opt/kde/lib ; rm -rf libartsgui_kde.so )
-( cd opt/kde/lib ; ln -sf libartsgui_kde.so.0.0.0 libartsgui_kde.so )
 ( cd opt/kde/lib ; rm -rf libarts_mpeglib-0.3.0.so.0 )
 ( cd opt/kde/lib ; ln -sf libarts_mpeglib-0.3.0.so.0.0.3 libarts_mpeglib-0.3.0.so.0 )
-( cd opt/kde/lib ; rm -rf libnoatuntags.so.0 )
-( cd opt/kde/lib ; ln -sf libnoatuntags.so.0.0.0 libnoatuntags.so.0 )
-( cd opt/kde/lib ; rm -rf libyafcore.so.0 )
-( cd opt/kde/lib ; ln -sf libyafcore.so.0.0.0 libyafcore.so.0 )
-( cd opt/kde/lib ; rm -rf libartsmodules.so.0 )
-( cd opt/kde/lib ; ln -sf libartsmodules.so.0.0.0 libartsmodules.so.0 )
-( cd opt/kde/lib ; rm -rf libnoatuncontrols.so.0 )
-( cd opt/kde/lib ; ln -sf libnoatuncontrols.so.0.0.0 libnoatuncontrols.so.0 )
-( cd opt/kde/lib ; rm -rf libnoatuntags.so )
-( cd opt/kde/lib ; ln -sf libnoatuntags.so.0.0.0 libnoatuntags.so )
-( cd opt/kde/lib ; rm -rf libworkman.so.1 )
-( cd opt/kde/lib ; ln -sf libworkman.so.1.4.3 libworkman.so.1 )
-( cd opt/kde/lib ; rm -rf libartsmodules.so )
-( cd opt/kde/lib ; ln -sf libartsmodules.so.0.0.0 libartsmodules.so )
-( cd opt/kde/lib ; rm -rf libartsgui_idl.so.0 )
-( cd opt/kde/lib ; ln -sf libartsgui_idl.so.0.0.0 libartsgui_idl.so.0 )
-( cd opt/kde/lib ; rm -rf libarts_splay.so )
-( cd opt/kde/lib ; ln -sf libarts_splay.so.0.0.0 libarts_splay.so )
-( cd opt/kde/lib ; rm -rf libartsgui.so )
-( cd opt/kde/lib ; ln -sf libartsgui.so.0.0.0 libartsgui.so )
-( cd opt/kde/lib ; rm -rf libartsgui_kde.so.0 )
-( cd opt/kde/lib ; ln -sf libartsgui_kde.so.0.0.0 libartsgui_kde.so.0 )
-( cd opt/kde/lib ; rm -rf libyafxplayer.so )
-( cd opt/kde/lib ; ln -sf libyafxplayer.so.0.0.0 libyafxplayer.so )
-( cd opt/kde/lib ; rm -rf libarts_splay.so.0 )
-( cd opt/kde/lib ; ln -sf libarts_splay.so.0.0.0 libarts_splay.so.0 )
-( cd opt/kde/lib ; rm -rf libartsmidi.so.0 )
-( cd opt/kde/lib ; ln -sf libartsmidi.so.0.0.0 libartsmidi.so.0 )
-( cd opt/kde/lib ; rm -rf libartsbuilder.so.0 )
-( cd opt/kde/lib ; ln -sf libartsbuilder.so.0.0.0 libartsbuilder.so.0 )
 ( cd opt/kde/lib ; rm -rf libarts_mpeglib.so )
 ( cd opt/kde/lib ; ln -sf libarts_mpeglib-0.3.0.so.0.0.3 libarts_mpeglib.so )
-( cd opt/kde/lib ; rm -rf libnoatun.so.0 )
-( cd opt/kde/lib ; ln -sf libnoatun.so.0.0.0 libnoatun.so.0 )
+( cd opt/kde/lib ; rm -rf libarts_splay.so )
+( cd opt/kde/lib ; ln -sf libarts_splay.so.0.0.0 libarts_splay.so )
+( cd opt/kde/lib ; rm -rf libarts_splay.so.0 )
+( cd opt/kde/lib ; ln -sf libarts_splay.so.0.0.0 libarts_splay.so.0 )
 ( cd opt/kde/lib ; rm -rf libartsbuilder.so )
 ( cd opt/kde/lib ; ln -sf libartsbuilder.so.0.0.0 libartsbuilder.so )
-( cd opt/kde/share/doc/HTML/en/kmid ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kmid ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kmix ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kmix ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/krec ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/krec ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kscd ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kscd ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kaboodle ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kaboodle ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kmidi ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kmidi ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/aktion ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/aktion ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kmixcfg ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/artsbuilder ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/en/common common )
-( cd opt/kde/share/doc/HTML/en/noatun ; rm -rf common )
-( cd opt/kde/share/doc/HTML/en/noatun ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/lib ; rm -rf libartsbuilder.so.0 )
+( cd opt/kde/lib ; ln -sf libartsbuilder.so.0.0.0 libartsbuilder.so.0 )
+( cd opt/kde/lib ; rm -rf libartscontrolapplet.so )
+( cd opt/kde/lib ; ln -sf libartscontrolapplet.so.1.0.0 libartscontrolapplet.so )
+( cd opt/kde/lib ; rm -rf libartscontrolapplet.so.1 )
+( cd opt/kde/lib ; ln -sf libartscontrolapplet.so.1.0.0 libartscontrolapplet.so.1 )
+( cd opt/kde/lib ; rm -rf libartscontrolsupport.so )
+( cd opt/kde/lib ; ln -sf libartscontrolsupport.so.1.0.0 libartscontrolsupport.so )
+( cd opt/kde/lib ; rm -rf libartscontrolsupport.so.1 )
+( cd opt/kde/lib ; ln -sf libartscontrolsupport.so.1.0.0 libartscontrolsupport.so.1 )
+( cd opt/kde/lib ; rm -rf libartsgui.so )
+( cd opt/kde/lib ; ln -sf libartsgui.so.0.0.0 libartsgui.so )
+( cd opt/kde/lib ; rm -rf libartsgui.so.0 )
+( cd opt/kde/lib ; ln -sf libartsgui.so.0.0.0 libartsgui.so.0 )
+( cd opt/kde/lib ; rm -rf libartsgui_idl.so )
+( cd opt/kde/lib ; ln -sf libartsgui_idl.so.0.0.0 libartsgui_idl.so )
+( cd opt/kde/lib ; rm -rf libartsgui_idl.so.0 )
+( cd opt/kde/lib ; ln -sf libartsgui_idl.so.0.0.0 libartsgui_idl.so.0 )
+( cd opt/kde/lib ; rm -rf libartsgui_kde.so )
+( cd opt/kde/lib ; ln -sf libartsgui_kde.so.0.0.0 libartsgui_kde.so )
+( cd opt/kde/lib ; rm -rf libartsgui_kde.so.0 )
+( cd opt/kde/lib ; ln -sf libartsgui_kde.so.0.0.0 libartsgui_kde.so.0 )
+( cd opt/kde/lib ; rm -rf libartsmidi.so )
+( cd opt/kde/lib ; ln -sf libartsmidi.so.0.0.0 libartsmidi.so )
+( cd opt/kde/lib ; rm -rf libartsmidi.so.0 )
+( cd opt/kde/lib ; ln -sf libartsmidi.so.0.0.0 libartsmidi.so.0 )
+( cd opt/kde/lib ; rm -rf libartsmidi_idl.so )
+( cd opt/kde/lib ; ln -sf libartsmidi_idl.so.0.0.0 libartsmidi_idl.so )
+( cd opt/kde/lib ; rm -rf libartsmidi_idl.so.0 )
+( cd opt/kde/lib ; ln -sf libartsmidi_idl.so.0.0.0 libartsmidi_idl.so.0 )
+( cd opt/kde/lib ; rm -rf libartsmodules.so )
+( cd opt/kde/lib ; ln -sf libartsmodules.so.0.0.0 libartsmodules.so )
+( cd opt/kde/lib ; rm -rf libartsmodules.so.0 )
+( cd opt/kde/lib ; ln -sf libartsmodules.so.0.0.0 libartsmodules.so.0 )
+( cd opt/kde/lib ; rm -rf libartsmodulescommon.so )
+( cd opt/kde/lib ; ln -sf libartsmodulescommon.so.0.0.0 libartsmodulescommon.so )
+( cd opt/kde/lib ; rm -rf libartsmodulescommon.so.0 )
+( cd opt/kde/lib ; ln -sf libartsmodulescommon.so.0.0.0 libartsmodulescommon.so.0 )
+( cd opt/kde/lib ; rm -rf libartsmoduleseffects.so )
+( cd opt/kde/lib ; ln -sf libartsmoduleseffects.so.0.0.0 libartsmoduleseffects.so )
+( cd opt/kde/lib ; rm -rf libartsmoduleseffects.so.0 )
+( cd opt/kde/lib ; ln -sf libartsmoduleseffects.so.0.0.0 libartsmoduleseffects.so.0 )
+( cd opt/kde/lib ; rm -rf libartsmodulesmixers.so )
+( cd opt/kde/lib ; ln -sf libartsmodulesmixers.so.0.0.0 libartsmodulesmixers.so )
+( cd opt/kde/lib ; rm -rf libartsmodulesmixers.so.0 )
+( cd opt/kde/lib ; ln -sf libartsmodulesmixers.so.0.0.0 libartsmodulesmixers.so.0 )
+( cd opt/kde/lib ; rm -rf libartsmodulessynth.so )
+( cd opt/kde/lib ; ln -sf libartsmodulessynth.so.0.0.0 libartsmodulessynth.so )
+( cd opt/kde/lib ; rm -rf libartsmodulessynth.so.0 )
+( cd opt/kde/lib ; ln -sf libartsmodulessynth.so.0.0.0 libartsmodulessynth.so.0 )
+( cd opt/kde/lib ; rm -rf libkcddb.so )
+( cd opt/kde/lib ; ln -sf libkcddb.so.1.0.0 libkcddb.so )
+( cd opt/kde/lib ; rm -rf libkcddb.so.1 )
+( cd opt/kde/lib ; ln -sf libkcddb.so.1.0.0 libkcddb.so.1 )
+( cd opt/kde/lib ; rm -rf libmpeg.so )
+( cd opt/kde/lib ; ln -sf libmpeg-0.3.0.so libmpeg.so )
+( cd opt/kde/lib ; rm -rf libnoatun.so )
+( cd opt/kde/lib ; ln -sf libnoatun.so.1.2.0 libnoatun.so )
+( cd opt/kde/lib ; rm -rf libnoatun.so.1 )
+( cd opt/kde/lib ; ln -sf libnoatun.so.1.2.0 libnoatun.so.1 )
+( cd opt/kde/lib ; rm -rf libnoatuncontrols.so )
+( cd opt/kde/lib ; ln -sf libnoatuncontrols.so.1.2.0 libnoatuncontrols.so )
+( cd opt/kde/lib ; rm -rf libnoatuncontrols.so.1 )
+( cd opt/kde/lib ; ln -sf libnoatuncontrols.so.1.2.0 libnoatuncontrols.so.1 )
+( cd opt/kde/lib ; rm -rf libnoatuntags.so )
+( cd opt/kde/lib ; ln -sf libnoatuntags.so.1.2.0 libnoatuntags.so )
+( cd opt/kde/lib ; rm -rf libnoatuntags.so.1 )
+( cd opt/kde/lib ; ln -sf libnoatuntags.so.1.2.0 libnoatuntags.so.1 )
+( cd opt/kde/lib ; rm -rf libworkman.so )
+( cd opt/kde/lib ; ln -sf libworkman.so.6.0.0 libworkman.so )
+( cd opt/kde/lib ; rm -rf libworkman.so.6 )
+( cd opt/kde/lib ; ln -sf libworkman.so.6.0.0 libworkman.so.6 )
+( cd opt/kde/lib ; rm -rf libyafcore.so )
+( cd opt/kde/lib ; ln -sf libyafcore.so.0.0.0 libyafcore.so )
+( cd opt/kde/lib ; rm -rf libyafcore.so.0 )
+( cd opt/kde/lib ; ln -sf libyafcore.so.0.0.0 libyafcore.so.0 )
+( cd opt/kde/lib ; rm -rf libyafxplayer.so )
+( cd opt/kde/lib ; ln -sf libyafxplayer.so.0.0.0 libyafxplayer.so )
+( cd opt/kde/lib ; rm -rf libyafxplayer.so.0 )
+( cd opt/kde/lib ; ln -sf libyafxplayer.so.0.0.0 libyafxplayer.so.0 )
